aboutsummaryrefslogtreecommitdiffstats
path: root/pkg
diff options
context:
space:
mode:
Diffstat (limited to 'pkg')
-rw-r--r--pkg/vcs/vcs.go4
-rw-r--r--pkg/vcs/vcs_test.go2
2 files changed, 3 insertions, 3 deletions
diff --git a/pkg/vcs/vcs_test.go b/pkg/vcs/vcs_test.go
index aa7210bf6..b53f65a93 100644
--- a/pkg/vcs/vcs_test.go
+++ b/pkg/vcs/vcs_test.go
@@ -126,7 +126,7 @@ func TestCommitLink(t *testing.T) {
{
"https://fuchsia.googlesource.com",
"13ee3dc5e4c46bf127977ad28645c47442ec517d",
- "https://fuchsia.googlesource.com/zircon/+/13ee3dc5e4c46bf127977ad28645c47442ec517d^!",
+ "https://fuchsia.googlesource.com/fuchsia/+/13ee3dc5e4c46bf127977ad28645c47442ec517d^!",
},
{
"git://git.cmpxchg.org/linux-mmots.git",
diff --git a/pkg/vcs/vcs.go b/pkg/vcs/vcs.go
index 8026bbfd5..77b919d4b 100644
--- a/pkg/vcs/vcs.go
+++ b/pkg/vcs/vcs.go
@@ -231,8 +231,8 @@ func link(url, hash string, typ int) string {
}
switch url {
case "https://fuchsia.googlesource.com":
- // We collect hashes from zircon repo.
- return link(url+"/zircon", hash, typ)
+ // We collect hashes from the fuchsia repo.
+ return link(url+"/fuchsia", hash, typ)
}
if strings.HasPrefix(url, "https://github.com/") {
url = strings.TrimSuffix(url, ".git")